@@ -11,6 +11,9 @@ xplr.config.general.show_hidden = false
 ------ Read only
 xplr.config.general.read_only = false
 
+------ Recover mode
+xplr.config.general.disable_recover_mode = false
+
 ------ Prompt
 xplr.config.general.prompt.format = "❯ "
 xplr.config.general.prompt.style.add_modifiers = nil
@@ -1342,9 +1345,10 @@ xplr.config.modes.builtin.action = {
         }
       },
       ["q"] = {
-        help = "quit",
+        help = "quit options",
         messages = {
-          "Quit",
+          "PopMode",
+          { SwitchModeBuiltin = "quit" },
         }
       }
     },
@@ -1364,6 +1368,59 @@ xplr.config.modes.builtin.action = {
   }
 }
 
+------ Quit
+xplr.config.modes.builtin.quit = {
+  name = "quit",
+  help = nil,
+  extra_help = nil,
+  key_bindings = {
+    on_key = {
+      enter = {
+        help = "just quit",
+        messages = {
+          "Quit",
+        }
+      },
+      p = {
+        help = "quit printing pwd",
+        messages = {
+          "PrintPwdAndQuit",
+        }
+      },
+      f = {
+        help = "quit printing focus",
+        messages = {
+          "PrintFocusPathAndQuit",
+        }
+      },
+      s = {
+        help = "quit printing selection",
+        messages = {
+          "PrintSelectionAndQuit",
+        }
+      },
+      r = {
+        help = "quit printing result",
+        messages = {
+          "PrintResultAndQuit",
+        }
+      },
+      esc = {
+        help = "cancel",
+        messages = {
+          "PopMode",
+        }
+      },
+      ["ctrl-c"] = {
+        help = "terminate",
+        messages = {
+          "Terminate",
+        }
+      }
+    }
+  }
+}
+
 ------ Search
 xplr.config.modes.builtin.search = {
   name = "search",
